Support a list of actions for a set speed event

Each set speed event will contain a list of one-to-many actions to
perform for the given event group's property. This reduces the amount of
code generated and properly handles property changed events against the
group.

Change-Id: If2b8c0d0b8ecf6e1c974c43d96e1c6e9e952022b
Signed-off-by: Matthew Barth <msbarth@us.ibm.com>
diff --git a/control/zone.hpp b/control/zone.hpp
index cb1ce69..bc21b9f 100644
--- a/control/zone.hpp
+++ b/control/zone.hpp
@@ -243,12 +243,12 @@
 
         /**
          * @brief Callback function for event timers that processes the given
          * action for a group
          *
          * @param[in] eventGroup - Group to process action on
          * @param[in] eventAction - Event action to run
          */
-        void timerExpired(Group eventGroup, Action eventAction);
+        void timerExpired(Group eventGroup, std::vector<Action> eventActions);
 
     private:
@@ -243,12 +243,12 @@
         /**
          * @brief Callback function for event timers that processes the given
-         * action for a group
+         * actions for a group
          *
@@ -243,12 +243,12 @@
          *
-         * @param[in] eventGroup - Group to process action on
-         * @param[in] eventAction - Event action to run
+         * @param[in] eventGroup - Group to process actions on
+         * @param[in] eventActions - List of event actions to run
          */